DiConfigurationClosedException class final
Thrown when a retained binder is used after configuration completes.
- Inheritance
-
- Object
- DiException
- DiConfigurationClosedException
Constructors
- DiConfigurationClosedException()
-
Creates an error for mutation through an expired binder.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited