DiCloseException class final
Thrown after close attempted every teardown operation and some failed.
- Inheritance
-
- Object
- DiException
- DiCloseException
Constructors
-
DiCloseException(Iterable<
DiCloseFailure> failures) -
Creates an aggregate from all observed teardown
failures.
Properties
-
failures
→ List<
DiCloseFailure> -
The immutable ordered list of teardown failures.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the failure.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited